@@ -1,8 +1,8 @@
-(*----------------------------------------------------------------------------
-   Copyright (c) 2009-2010, Daniel C. Bünzli. All rights reserved.
-   Distributed under a BSD license, see license at the end of the file.
-   react version 0.9.2
-  ----------------------------------------------------------------------------*)
+(*---------------------------------------------------------------------------
+   Copyright (c) 2009-2012 Daniel C. Bünzli. All rights reserved.
+   Distributed under a BSD3 license, see license at the end of the file.
+   react release 0.9.3
+  ---------------------------------------------------------------------------*)
 
 let err_max_rank = "maximal rank exceeded"
 let err_sig_undef = "signal value undefined yet"
@@ -1321,8 +1321,8 @@ module S = struct
   end
 end
 
-(*----------------------------------------------------------------------------
-  Copyright (c) 2009-2010, Daniel C. Bünzli
+(*---------------------------------------------------------------------------
+  Copyright (c) 2009-2012 Daniel C. Bünzli
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -1337,7 +1337,7 @@ end
      documentation and/or other materials provided with the
      distribution.
 
-  3. Neither the name of the Daniel C. Bünzli nor the names of
+  3. Neither the name of Daniel C. Bünzli nor the names of
      contributors may be used to endorse or promote products derived
      from this software without specific prior written permission.
 
@@ -1352,4 +1352,4 @@ end
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-  ----------------------------------------------------------------------------*)
+  ---------------------------------------------------------------------------*)
