@@ -1,26 +1,24 @@
-(*----------------------------------------------------------------------------
-   Copyright (c) 2009-2010, Daniel C. Bünzli. All rights reserved.
-   Distributed under a BSD license, see license at the end of the file.
-   React version 0.9.2
-  ----------------------------------------------------------------------------*)
+(*---------------------------------------------------------------------------
+   Copyright (c) 2009-2012 Daniel C. Bünzli. All rights reserved.
+   Distributed under a BSD3 license, see license at the end of the file.
+   react release 0.9.3
+  ---------------------------------------------------------------------------*)
 
-(** Applicative events and signals.
+(** Declarative events and signals.
 
     React is a module for functional reactive programming (frp).  It
-    provides support to program with time varying values : applicative
+    provides support to program with time varying values : declarative
     {{:React.E.html}events} and {{:React.S.html}signals}. React
     doesn't define any primitive event or signal, this lets the client
     choose the concrete timeline.
 
     Consult the {{:#sem}semantics}, the {{:#basics}basics} and
-    {{:#ex}examples}.  
+    {{:#ex}examples}. Open the module to use it, this defines only two
+    types and modules in your scope.
 
-    Open the module to use it. This defines only two types and two modules
-    in your scope. 
-
-    {e Version 0.9.2 - daniel.buenzl i\@erratique.ch }
+    {e Release 0.9.3 - Daniel Bünzli <daniel.buenzli at erratique.ch> } *)
     
-    {1:top  } *)
+(**    {1 Interface} *)
 
 type 'a event
 (** The type for events of type ['a]. *)
@@ -884,8 +882,8 @@ let printer = E.map pr_time seconds
 let () = run ()]}
 *)
 
-(*----------------------------------------------------------------------------
-  Copyright (c) 2009-2010, Daniel C. Bünzli
+(*---------------------------------------------------------------------------
+  Copyright (c) 2009-2012 Daniel C. Bünzli
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -900,7 +898,7 @@ let () = run ()]}
      documentation and/or other materials provided with the
      distribution.
 
-  3. Neither the name of the Daniel C. Bünzli nor the names of
+  3. Neither the name of Daniel C. Bünzli nor the names of
      contributors may be used to endorse or promote products derived
      from this software without specific prior written permission.
 
@@ -915,4 +913,4 @@ let () = run ()]}
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-  ----------------------------------------------------------------------------*)
+  ---------------------------------------------------------------------------*)
